==> haskell-cprng-aes-0.6.1-119-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cprng-aes
version:              0.6.1
visibility:           public
id:                   cprng-aes-0.6.1-5TQ8fBQ7QhR4eP7PH7KoHO
key:                  cprng-aes-0.6.1-5TQ8fBQ7QhR4eP7PH7KoHO
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cprng-aes
synopsis:
    Crypto Pseudo Random Number Generator using AES in counter mode.

description:
    Simple crypto pseudo-random-number-generator with really good randomness property.

    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)

    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).

category:             Cryptography
abi:                  da03a5430d3812a45f97057591d18a32
exposed:              True
exposed-modules:      Crypto.Random.AESCtr
hidden-modules:       Crypto.Random.AESCtr.Internal
import-dirs:          /usr/lib/ghc-8.8.1/site-local/cprng-aes-0.6.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cprng-aes
hs-libraries:         HScprng-aes-0.6.1-5TQ8fBQ7QhR4eP7PH7KoHO
depends:
    base-4.13.0.0 byteable-0.1.1-8StI3PhRPjVAHxdIrDquyO
    bytestring-0.10.9.0 cipher-aes-0.2.11-5TCtpIdHIpvKnqtx0Yqdci
    crypto-random-0.0.9-IzbkpBnLpztFWOpgDq6hn9

haddock-interfaces:   /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html:         /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cprng-aes-0.6.1-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cprng-aes
version:              0.6.1
visibility:           public
id:                   cprng-aes-0.6.1-AuBF1JHSod1ddnEyqXw4j
key:                  cprng-aes-0.6.1-AuBF1JHSod1ddnEyqXw4j
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cprng-aes
synopsis:
    Crypto Pseudo Random Number Generator using AES in counter mode.

description:
    Simple crypto pseudo-random-number-generator with really good randomness property.

    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)

    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).

category:             Cryptography
abi:                  af688d106e3c5759c6fff0d70c7a2302
exposed:              True
exposed-modules:      Crypto.Random.AESCtr
hidden-modules:       Crypto.Random.AESCtr.Internal
import-dirs:          /usr/lib/ghc-8.8.2/site-local/cprng-aes-0.6.1
library-dirs:         /usr/lib/ghc-8.8.2/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cprng-aes
hs-libraries:         HScprng-aes-0.6.1-AuBF1JHSod1ddnEyqXw4j
depends:
    base-4.13.0.0 byteable-0.1.1-8Mf9i6aHWXD4KcleGSFFs
    bytestring-0.10.10.0 cipher-aes-0.2.11-AERrjrA3qzzIeotuFNCXm7
    crypto-random-0.0.9-DwT9uyAWaNpGoyJgWOusfP

haddock-interfaces:   /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html:         /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
